PROGRAM_NAME='E - Demo main program for EIB access'
(*   DATE:01/11/00    TIME:11:39:59    *)

DEFINE_DEVICE
  EIB  =  17 (* Device ID of AXB-232++/AXC-232++ *)
  TP   = 128 (* Any control device, i.e. AXT-EL+ *)

DEFINE_CONSTANT
  Sw_Light1    = 1 (* Switch number light 1 *)
  Sw_Light2    = 2 (* Switch number light 2 *)
  Sw_Light3    = 3 (* Switch number light 3 *)
  Sw_Dimmer    = 4 (* Switch dimmer on/off *)

  D4_Dimmer    = 1 (* Dimming relative *)

  B1_Dim_Set   = 1 (* Dimming absolute *)
  B1_Dim_Val   = 2 (* Dimmer value *)

DEFINE_CONNECT_LEVEL
  (EIB,B1_Dim_Val,TP,1) (* Display brightness on bargraph #1 *)

DEFINE_VARIABLE
  EIB_Buffer[255]   (* Receive buffer of the box *)
  INTEGER EIB_Switch[255]   (* Actual Switch values *)
  INTEGER EIB_Dim4[255]     (* Actual Dim4 values *)
  INTEGER EIB_1Byte[255]    (* Actual 1Byte values *)

DEFINE_START
  CREATE_BUFFER EIB,EIB_Buffer (* Connect receive buffer *)

DEFINE_PROGRAM
(* Read in feedbacks *)
SYSTEM_CALL 'EIB Read Standard' (EIB_Buffer,EIB_Switch,EIB_Dim4,EIB_1Byte)

(* Switch light1, one button each for 'On' and 'Off' *)
PUSH[TP,1] (* Light1 on *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Light1)

PUSH[TP,2] (* Light1 off *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Light1)

[TP,1] = [EIB,Sw_Light1]     (* Feedback 'on' *)
[TP,2] = not [EIB,Sw_Light1] (* Feedback 'off' *)

(* Switch light2, one button toggles between 'on' and 'off' *)
PUSH[TP,3] (* Light2 on/off *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,not [EIB,Sw_Light2],Sw_Light2)

[TP,3] = [EIB,Sw_Light2]     (* Feedback 'on' *)

(* Switch light3, button switches on for 10 seconds *)
PUSH[TP,4] (* Light3 on for 10 secs *)
  {
  CANCEL_WAIT 'Light3'
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Light3)
  WAIT 100 'Light3'
    SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Light3)
  }

[TP,4] = [EIB,Sw_Light3]     (* Feedback 'on' *)

(* Dimmer control *)
PUSH[TP,5] (* Dimmer off *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,0,Sw_Dimmer)

PUSH[TP,6] (* Dimmer to 25% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,64,B1_Dim_Set)

PUSH[TP,7] (* Dimmer to 50% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,128,B1_Dim_Set)

PUSH[TP,8] (* Dimmer to 75% *)
  SYSTEM_CALL 'EIB Set 1Byte' (EIB,192,B1_Dim_Set)

PUSH[TP,9] (* Dimmer to 100% *)
  SYSTEM_CALL 'EIB Set Switch' (EIB,1,Sw_Dimmer)

[TP,5] = (EIB_1Byte[B1_Dim_Val] = 0)   (* Feedback 0% *)
[TP,6] = (EIB_1Byte[B1_Dim_Val] = 64)  (* Feedback 25% *)
[TP,7] = (EIB_1Byte[B1_Dim_Val] = 128) (* Feedback 50% *)
[TP,8] = (EIB_1Byte[B1_Dim_Val] = 192) (* Feedback 75% *)
[TP,9] = (EIB_1Byte[B1_Dim_Val] = 255) (* Feedback 100% *)

PUSH[TP,10] (* Brighter *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,10,D4_Dimmer)

PUSH[TP,11] (* Darker *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,2,D4_Dimmer)

RELEASE[TP,10] (* Bright enough *)
RELEASE[TP,11] (* Dark enough *)
  SYSTEM_CALL 'EIB Set Dim4' (EIB,0,D4_Dimmer)

[TP,10] = ((EIB_Dim4[D4_Dimmer] >= 9) and (EIB_Dim4[D4_Dimmer] <= 15))
[TP,11] = ((EIB_Dim4[D4_Dimmer] >= 1) and (EIB_Dim4[D4_Dimmer] <= 7))

